@@ -14,17 +14,16 @@ use Getopt::Std;
 $opt_j = 0;
 getopts('j');
 
-if (@ARGV < 1)
-{
-	die <<EOF
+if (@ARGV < 1) {
+    die <<EOF
 	usage: perl $0 [-j] zipfile.zip
 	if -j option given, discards paths.
 EOF
 }
 
-my $zip = Archive::Zip->new();
+my $zip     = Archive::Zip->new();
 my $zipName = shift(@ARGV);
-my $status = $zip->read( $zipName );
+my $status  = $zip->read($zipName);
 die "Read of $zipName failed\n" if $status != AZ_OK;
 
 $zip->extractTree();
